@@ -7,6 +7,7 @@ import (
 	"fmt"
 	"os"
 	"regexp"
+	"strconv"
 	"strings"
 	"sync"
 	"sync/atomic"
@@ -25,9 +26,9 @@ import (
 	"github.com/StackExchange/dnscontrol/v4/pkg/normalize"
 	"github.com/StackExchange/dnscontrol/v4/pkg/notifications"
 	"github.com/StackExchange/dnscontrol/v4/pkg/printer"
+	"github.com/StackExchange/dnscontrol/v4/pkg/providers"
 	"github.com/StackExchange/dnscontrol/v4/pkg/rfc4183"
 	"github.com/StackExchange/dnscontrol/v4/pkg/zonerecs"
-	"github.com/StackExchange/dnscontrol/v4/providers"
 )
 
 type cmdZoneCache struct {
@@ -210,8 +211,30 @@ func prun(args PPreviewArgs, push bool, interactive bool, out printer.CLI, repor
 		return err
 	}
 
+	var notify = args.Notify
+
+	// We want to notify if args.Notify OR notify_on_*
+	if notifications, ok := providerConfigs["notifications"]; ok && notifications != nil {
+		if push {
+			if notifyOnPush, ok := notifications["notify_on_push"]; ok {
+				if b, _ := strconv.ParseBool(notifyOnPush); b {
+					notify = true
+				}
+			}
+		} else {
+			if notifyOnPreview, ok := notifications["notify_on_preview"]; ok {
+				if b, _ := strconv.ParseBool(notifyOnPreview); b {
+					notify = true
+				}
+			}
+		}
+	}
+	if notify {
+		out.PrintfIf(fullMode, "Notifications are enabled...\n")
+	}
+
 	out.PrintfIf(fullMode, "Creating an in-memory model of 'desired'...\n")
-	notifier, err := PInitializeProviders(cfg, providerConfigs, args.Notify)
+	notifier, err := PInitializeProviders(cfg, providerConfigs, notify)
 	if err != nil {
 		return err
 	}
@@ -240,7 +263,7 @@ func prun(args PPreviewArgs, push bool, interactive bool, out printer.CLI, repor
 		t := throttler.New(args.ConcurMax, len(zonesConcurrent))
 		out.Printf("CONCURRENTLY checking for %d zone(s)\n", len(zonesConcurrent))
 		for i, zone := range zonesConcurrent {
-			out.PrintfIf(fullMode, "Concurrently checking for zone: %q\n", zone.Name)
+			out.PrintfIf(fullMode, "Concurrently checking for zone: %q\n", zone.UniqueName)
 			go func(zone *models.DomainConfig) {
 				start := time.Now()
 				err := oneZonePopulate(zone, zcache)
@@ -261,7 +284,7 @@ func prun(args PPreviewArgs, push bool, interactive bool, out printer.CLI, repor
 
 		out.Printf("SERIALLY checking for %d zone(s)\n", len(zonesSerial))
 		for _, zone := range zonesSerial {
-			out.Printf("Serially checking for zone: %q\n", zone.Name)
+			out.Printf("Serially checking for zone: %q\n", zone.UniqueName)
 			if err := oneZonePopulate(zone, zcache); err != nil {
 				anyErrors = true
 			}
@@ -308,7 +331,7 @@ func prun(args PPreviewArgs, push bool, interactive bool, out printer.CLI, repor
 	t := throttler.New(args.ConcurMax, len(zonesConcurrent))
 	out.Printf("CONCURRENTLY gathering records of %d zone(s)\n", len(zonesConcurrent))
 	for i, zone := range zonesConcurrent {
-		out.PrintfIf(fullMode, "Concurrently gathering: %q\n", zone.Name)
+		out.PrintfIf(fullMode, "Concurrently gathering: %q\n", zone.UniqueName)
 		go func(zone *models.DomainConfig, args PPreviewArgs, zcache *cmdZoneCache) {
 			start := time.Now()
 			err := oneZone(zone, args)
@@ -328,7 +351,7 @@ func prun(args PPreviewArgs, push bool, interactive bool, out printer.CLI, repor
 	}
 	out.Printf("SERIALLY gathering records of %d zone(s)\n", len(zonesSerial))
 	for _, zone := range zonesSerial {
-		out.Printf("Serially Gathering: %q\n", zone.Name)
+		out.Printf("Serially Gathering: %q\n", zone.UniqueName)
 		if err := oneZone(zone, args); err != nil {
 			anyErrors = true
 		}
